==> _private_core_network-0.0.75.tar.gz: lib/network_resources/model/homelido_meeting.dart <==
import '_model.dart';

class HomelidoMeeting {
  String? id;
  int? propertyId;
  int? userIdPresentor;
  int? userIdVisitor;
  int? meetingDatetime;
  int? status;
  HomelidoPropertyInfo? homelidoPropertyInfo;

  //This info will have value in list events
  ProsModel? proInfo;
  UserModel? userInfo;

  HomelidoMeeting(
      {this.id,
      this.propertyId,
      this.userIdPresentor,
      this.userIdVisitor,
      this.meetingDatetime,
      this.status,
      this.homelidoPropertyInfo});

  HomelidoMeeting.fromJson(Map<String, dynamic> json) {
    proInfo = ProsModel.fromJson(json['proInfo'] ?? {});
    userInfo = UserModel.fromJson(json['userInfo'] ?? {});
    if (json["id"] is String) this.id = json["id"];
    if (json["propertyId"] is int) this.propertyId = json["propertyId"];
    if (json["userIdPresentor"] is int)
      this.userIdPresentor = json["userIdPresentor"];
    if (json["userIdVisitor"] is int)
      this.userIdVisitor = json["userIdVisitor"];
    if (json["meetingDatetime"] is int)
      this.meetingDatetime = json["meetingDatetime"];
    if (json["status"] is int) this.status = json["status"];
    if (json['homelidoPropertyInfo'] != null)
      homelidoPropertyInfo =
          HomelidoPropertyInfo.fromJson(json['homelidoPropertyInfo']);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["propertyId"] = this.propertyId;
    data["userIdPresentor"] = this.userIdPresentor;
    data["userIdVisitor"] = this.userIdVisitor;
    data["meetingDatetime"] = this.meetingDatetime;
    data["status"] = this.status;
    data["homelidoPropertyInfo"] = this.homelidoPropertyInfo?.toJson();
    data["proInfo"] = this.proInfo?.toJson();
    data["userInfo"] = this.userInfo?.toJson();
    return data;
  }
}

==> _private_core_network-1.1.5.tar.gz: lib/network_resources/model/homelido_meeting.dart <==
import '_model.dart';

class HomelidoMeeting {
  String? id;
  int? propertyId;
  int? userIdPresentor;
  int? userIdVisitor;
  int? meetingDatetime;
  int? status;
  HomeDetailInfo? homelidoPropertyInfo;

  //This info will have value in list events
  ProsModel? proInfo;
  UserModel? userInfo;

  HomelidoMeeting(
      {this.id,
      this.propertyId,
      this.userIdPresentor,
      this.userIdVisitor,
      this.meetingDatetime,
      this.status,
      this.homelidoPropertyInfo});

  HomelidoMeeting.fromJson(Map<String, dynamic> json) {
    proInfo = ProsModel.fromJson(json['proInfo'] ?? {});
    userInfo = UserModel.fromJson(json['userInfo'] ?? {});
    if (json["id"] is String) this.id = json["id"];
    if (json["propertyId"] is int) this.propertyId = json["propertyId"];
    if (json["userIdPresentor"] is int)
      this.userIdPresentor = json["userIdPresentor"];
    if (json["userIdVisitor"] is int)
      this.userIdVisitor = json["userIdVisitor"];
    if (json["meetingDatetime"] is int)
      this.meetingDatetime = json["meetingDatetime"];
    if (json["status"] is int) this.status = json["status"];
    if (json['homelidoPropertyInfo'] != null)
      homelidoPropertyInfo =
          HomeDetailInfo.fromJson(json['homelidoPropertyInfo']);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["id"] = this.id;
    data["propertyId"] = this.propertyId;
    data["userIdPresentor"] = this.userIdPresentor;
    data["userIdVisitor"] = this.userIdVisitor;
    data["meetingDatetime"] = this.meetingDatetime;
    data["status"] = this.status;
    data["homelidoPropertyInfo"] = this.homelidoPropertyInfo?.toJson();
    data["proInfo"] = this.proInfo?.toJson();
    data["userInfo"] = this.userInfo?.toJson();
    return data;
  }
}
